@@ -6,6 +6,8 @@
 //! - Cloud Foundry app instance set variables, most of the times starting with `CF_`
 //!
 //! It's meant to get you away from boilerplating and get you started with typed variables while keeping simplicity
+#![deny(clippy::all, clippy::cargo)]
+#![forbid(unsafe_code)]
 
 pub mod constants;
 pub mod enums;
@@ -24,7 +26,9 @@ use std::panic;
 use std::path::PathBuf;
 use std::str::FromStr;
 
-/// Checks if `VCAP_APPLICATION` is defined, if so uses as the indicator that the app is running in a Cloud Foundry Environment
+/// Checks if `VCAP_APPLICATION` is defined, if so uses as the indicator that the app is running in a Cloud Foundry Environment.
+///
+/// Use this with caution. To use the flexibility of cargo and optimization of rust and llvm you should only use this if there is no other way. One other possible way would be to use features flags for your binaries and use them to identify for which environment you build.
 pub fn is_cf_env() -> bool {
     env::var(VCAP_APPLICATION).is_ok()
 }
